@@ -17,7 +17,7 @@ sub __is_power__ {
 
     # Don't accept a non-positive power
     # Also, when $x is negative and $y is even, return faster
-    if ($y <= 0 or ($y % 2 == 0 and Math::GMPq::Rmpq_sgn($x) < 0)) {
+    if ($y <= 0 or ($y % 2 == 0 and Math::GMPz::Rmpz_sgn($x) < 0)) {
         return 0;
     }
 
@@ -25,8 +25,8 @@ sub __is_power__ {
     $y == 2 and return Math::GMPz::Rmpz_perfect_square_p($x);
 
     Math::GMPz::Rmpz_perfect_power_p($x) || return 0;
-    my $z = Math::GMPz::Rmpz_init_set($x);
-    Math::GMPz::Rmpz_root($z, $z, $y);
+    state $t = Math::GMPz::Rmpz_init_nobless();
+    Math::GMPz::Rmpz_root($t, $x, $y);
 }
 
 1;
